/*
    test.c
    Copyright 1998, 1999 by Richard Dawe    

    ---

    Demo of UNC file-system extension.
*/

#include <errno.h>
#include <io.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "../src/unc_fsx.h"

int main (int argc, char *argv[])
{
    char *unc = NULL;   /* Copy of filename argument */
    FILE *fUnc = NULL;  /* FILE pointer              */
    int hUnc = 0;       /* File handle (descriptor)  */

    /* Initialise the UNC file-system extension. This will be uninitialised
       automatically on exit. */
    if (!unc_fsext_init()) return(0);

    /* Check the args */
    if (argc < 2) {        
        printf("%s, Copyright 1998 by Richard Dawe\n"
               "DJGPP UNC file-system extension test program\n\n"
               "Syntax: %s <UNC file name>\n\n"
               "e.g. %s \\\\myhost\\myshare\\mydir\\myfile.txt\n",
               argv[0], argv[0], argv[0]);
        return(0);
    }

    /* Try opening the file and counting the number of bytes. */
    unc = strdup(argv[1]);
    fUnc = fopen(unc, "rb");

    if (fUnc == NULL) {
        fprintf(stderr, "%s: %s\n", argv[0], strerror(errno));
        free(unc);
        return(0);
    }

    /* The UNC path is mapped to a drive, and the contents of unc are
       modified so that the filename points to the mapped drive, e.g.
       \\myhost\myshare -> Z: */
    printf("UNC mapping: %s -> %s\n", argv[1], unc);

    hUnc = fileno(fUnc);
    printf("UNC file size = %li\n", filelength(hUnc));

    fclose(fUnc);
    free(unc);

    /* OK */
    return(1);
}
